SET NOCOUNT ON

CREATE TABLE document_type_format (
       dctf_value           nvarchar(255) NULL,
       dtfc_code            nvarchar(20) NOT NULL,
       dcty_code            nvarchar(10) NOT NULL
)
go

CREATE INDEX xif1document_type_format ON document_type_format
(
       dtfc_code
)
go

CREATE INDEX xif2document_type_format ON document_type_format
(
       dcty_code
)
go

ALTER TABLE document_type_format
       ADD CONSTRAINT xpkdocument_type_format PRIMARY KEY (dtfc_code, 
              dcty_code)
go

CREATE TABLE document_type_format_code (
       dtfc_code            nvarchar(20) NOT NULL,
       dtfc_name            nvarchar(50) NOT NULL
)
go

ALTER TABLE document_type_format_code
       ADD CONSTRAINT xpkdocument_type_format_code PRIMARY KEY (
              dtfc_code)
go

ALTER TABLE document_type_format
       ADD CONSTRAINT r_191
              FOREIGN KEY (dcty_code)
                             REFERENCES document_type  (dcty_code)
go

ALTER TABLE document_type_format
       ADD CONSTRAINT r_dtfc_dctf
              FOREIGN KEY (dtfc_code)
                             REFERENCES document_type_format_code  (
              dtfc_code)
go

ALTER TABLE archive_profile DROP
CONSTRAINT r_dcty_aprf
go

DROP INDEX archive_profile.xif3archive_profile
go
ALTER TABLE archive_profile ALTER COLUMN dcty_code nvarchar (10)  NULL
GO

CREATE NONCLUSTERED INDEX xif3archive_profile ON archive_profile (dcty_code)
GO

ALTER TABLE archive_profile ADD
CONSTRAINT r_dcty_aprf FOREIGN KEY (dcty_code) REFERENCES document_type (dcty_code)
GO

ALTER TABLE archive_server DROP
CONSTRAINT r_dcty_asvr
GO

DROP INDEX archive_server.xif3archive_server
GO

ALTER TABLE archive_server ALTER COLUMN dcty_code nvarchar (10) NULL
GO

CREATE NONCLUSTERED INDEX xif3archive_server ON archive_server (dcty_code)
GO

ALTER TABLE archive_server ADD
CONSTRAINT r_dcty_asvr FOREIGN KEY (dcty_code) REFERENCES document_type (dcty_code)
GO

ALTER TABLE document_property ADD
docp_data_format nvarchar (255) NULL,
docp_column_number int NULL,
docp_utc_flag tinyint NULL
GO

ALTER TABLE expression_value ADD
eval_regexp_replace_string nvarchar (255) NULL
GO

ALTER TABLE filter_rule ADD
dcty_code nvarchar (10) NULL
GO

CREATE NONCLUSTERED INDEX xif3filter_rule ON filter_rule (dcty_code)
GO

ALTER TABLE filter_rule ADD
CONSTRAINT r_dcty_frul FOREIGN KEY (dcty_code) REFERENCES document_type (dcty_code)
GO

insert into document_type_format_code (dtfc_code,dtfc_name) values ( N'FORMAT_TYPE',N'Format Type')
insert into document_type_format_code (dtfc_code,dtfc_name) values ( N'DELIMITER',N'Delimter')
insert into document_type_format_code (dtfc_code,dtfc_name) values ( N'TEXT_QUALIFIER',N'Text Qualifier')
insert into document_type_format_code (dtfc_code,dtfc_name) values ( N'CODE_PAGE',N'Code Page')
insert into document_type_format_code (dtfc_code,dtfc_name) values ( N'FIRST_ROW_LABELS',N'First row contains labels')
insert into document_type_format_code (dtfc_code,dtfc_name) values ( N'REF_MULTIPLE_FILES',N'References multiple files')
insert into document_type_format_code (dtfc_code,dtfc_name) values ( N'MULTIVAL_DELIM',N'Multivalue delimiter')
go

INSERT INTO repository_archive_option_code (rocd_code, rpty_code, rocd_name) VALUES (N'CREATEFLD', N'P8_CE', N'Create Folder')
INSERT INTO repository_archive_option_code (rocd_code, rpty_code, rocd_name) VALUES (N'DOCCONTYPE', N'P8_CE', N'Doc Content Type')
go

INSERT INTO repository_property_class (rcls_code, rpty_code, rcls_name) VALUES (N'FOLDER', N'FILENET_CS', N'Folder')
INSERT INTO repository_property_class (rcls_code, rpty_code, rcls_name) VALUES (N'FOLDER', N'FILENET_IS', N'Folder')
INSERT INTO repository_property_class (rcls_code, rpty_code, rcls_name) VALUES (N'FOLDER', N'P8_CE', N'Folder')
INSERT INTO repository_property_class (rcls_code, rpty_code, rcls_name) VALUES (N'RMCLASSIFICATION', N'P8_CE', N'RM Classification')
go

CREATE TABLE extended_value_object_code (
       evot_code            nvarchar(20) NOT NULL,
       evot_name            nvarchar(20) NOT NULL
)
go

ALTER TABLE extended_value_object_code
       ADD CONSTRAINT xpkextended_value_object_code PRIMARY KEY (
              evot_code)
go

CREATE TABLE extended_value_type_code (
       evtc_code            nvarchar(20) NOT NULL,
       evtc_name            nvarchar(20) NOT NULL
)
go

ALTER TABLE extended_value_type_code
       ADD CONSTRAINT xpkextended_value_type_code PRIMARY KEY (
              evtc_code)
go

CREATE TABLE component_extended_value (
       cexv_id              int IDENTITY,
       cexv_value           nvarchar(255) NULL,
       cexv_object          nvarchar(255) NULL,
       comp_code            nvarchar(10) NULL,
       cccd_code            nvarchar(25) NULL,
       asvr_id              int NULL,
       evot_code            nvarchar(20) NULL,
       evtc_code            nvarchar(20) NULL
)
go

CREATE INDEX xif2component_extended_value ON component_extended_value
(
       comp_code,
       cccd_code,
       asvr_id
)
go

CREATE INDEX xif3component_extended_value ON component_extended_value
(
       evot_code
)
go

CREATE INDEX xif4component_extended_value ON component_extended_value
(
       evtc_code
)
go

ALTER TABLE component_extended_value
       ADD CONSTRAINT xpkcomponent_extended_value PRIMARY KEY (
              cexv_id)
go

ALTER TABLE component_extended_value
       ADD CONSTRAINT r_evtc_cexv
              FOREIGN KEY (evtc_code)
                             REFERENCES extended_value_type_code  (
              evtc_code)
go

ALTER TABLE component_extended_value
       ADD CONSTRAINT r_evot_cexv
              FOREIGN KEY (evot_code)
                             REFERENCES extended_value_object_code  (
              evot_code)
go

ALTER TABLE component_extended_value
       ADD CONSTRAINT r_coco_cexv
              FOREIGN KEY (comp_code, cccd_code, asvr_id)
                             REFERENCES component_config_option  (
              comp_code, cccd_code, asvr_id)
go

insert into extended_value_object_code (evot_code,evot_name) values ( N'USER',N'NT User')
insert into extended_value_object_code (evot_code,evot_name) values ( N'GROUP',N'NT Group')
insert into extended_value_object_code (evot_code,evot_name) values ( N'COMPUTER',N'Computer')
go

insert into extended_value_type_code (evtc_code,evtc_name) values ( N'0',N'Leave')
insert into extended_value_type_code (evtc_code,evtc_name) values ( N'1',N'Delete')
insert into extended_value_type_code (evtc_code,evtc_name) values ( N'2',N'Move')
insert into extended_value_type_code (evtc_code,evtc_name) values ( N'8',N'Rename')
insert into extended_value_type_code (evtc_code,evtc_name) values ( N'16',N'Tag')
insert into extended_value_type_code (evtc_code,evtc_name) values ( N'32',N'Security')
insert into extended_value_type_code (evtc_code,evtc_name) values ( N'64',N'Replicate')
go

CREATE TABLE captured_document (
       cdoc_document_key    nvarchar(255) NOT NULL,
       dupc_id              int NOT NULL,
       cdst_code            nvarchar(20) NOT NULL,
       cdoc_created_date    datetime NOT NULL,
       cdoc_modified_date   datetime NOT NULL
)
go

CREATE INDEX xif1captured_document ON captured_document
(
       dupc_id
)
go

CREATE INDEX xif2captured_document ON captured_document
(
       cdst_code
)
go


ALTER TABLE captured_document
       ADD CONSTRAINT xpkcaptured_document PRIMARY KEY (
              cdoc_document_key)
go


CREATE TABLE captured_document_state_code (
       cdst_code            nvarchar(20) NOT NULL,
       cdst_name            nvarchar(50) NOT NULL
)
go

ALTER TABLE captured_document_state_code
       ADD CONSTRAINT xpkcaptured_document_state_code PRIMARY KEY (
              cdst_code)
go

CREATE TABLE class_property_data_type_code (
       cpdc_code            nvarchar(20) NOT NULL,
       cpdc_name            nvarchar(50) NOT NULL
)
go

ALTER TABLE class_property_data_type_code
       ADD CONSTRAINT xpkclass_property_data_type_code PRIMARY KEY (
              cpdc_code)
go

CREATE TABLE duplicate_criteria (
       dupc_id              int IDENTITY,
       dupc_created_date    datetime NOT NULL,
       dupc_deleted_flag    tinyint NOT NULL,
       dupc_deleted_date    datetime NULL
)
go

ALTER TABLE duplicate_criteria
       ADD CONSTRAINT xpkduplicate_criteria PRIMARY KEY (dupc_id)
go

CREATE TABLE duplicate_criteria_fields (
       docp_code            nvarchar(10) NOT NULL,
       dcty_code            nvarchar(10) NOT NULL,
       dupc_id              int NOT NULL
)
go

CREATE INDEX xif1duplicate_criteria_fields ON duplicate_criteria_fields
(
       dupc_id
)
go

ALTER TABLE duplicate_criteria_fields
       ADD CONSTRAINT xpkduplicate_criteria_fields PRIMARY KEY (
              dupc_id, docp_code, dcty_code)
go

CREATE TABLE invocation_type_code (
       invt_code            nvarchar(20) NOT NULL,
       invt_name            nvarchar(50) NOT NULL
)
go

ALTER TABLE invocation_type_code
       ADD CONSTRAINT xpkinvocation_type_code PRIMARY KEY (invt_code)
go

CREATE TABLE monitored_location_optval (
       mlov_id              int IDENTITY,
       mlov_value           nvarchar(255) NULL,
       mloc_id              int NULL,
       movc_code            nvarchar(20) NOT NULL
)
go

CREATE INDEX xif1monitored_location_optval ON monitored_location_optval
(
       mloc_id
)
go

CREATE INDEX xif2monitored_location_optval ON monitored_location_optval
(
       movc_code
)
go

ALTER TABLE monitored_location_optval
       ADD CONSTRAINT xpkmonitored_location_optval PRIMARY KEY (
              mlov_id)
go

CREATE TABLE monitored_location_optval_code (
       movc_code            nvarchar(20) NOT NULL,
       movc_name            nvarchar(50) NOT NULL
)
go

ALTER TABLE monitored_location_optval_code
       ADD CONSTRAINT xpkmonitored_location_optval_code PRIMARY KEY (
              movc_code)
go

ALTER TABLE monitored_location_optval
       ADD CONSTRAINT r_movc_mlov
              FOREIGN KEY (movc_code)
                             REFERENCES monitored_location_optval_code  (
              movc_code)
go

ALTER TABLE monitored_location_optval
       ADD CONSTRAINT r_mlov_mloc
              FOREIGN KEY (mloc_id)
                             REFERENCES monitored_location  (mloc_id)
go

CREATE TABLE repository_class (
       repc_system_name     nvarchar(20) NOT NULL,
       repc_display_name    nvarchar(255) NOT NULL,
       repo_id              int NOT NULL
)
go

CREATE INDEX xif1repository_class ON repository_class
(
       repo_id
)
go

ALTER TABLE repository_class
       ADD CONSTRAINT xpkrepository_class PRIMARY KEY (
              repc_system_name)
go

CREATE TABLE repository_class_config_code (
       rccc_code            nvarchar(20) NOT NULL,
       rccc_name            nvarchar(50) NOT NULL
)
go

ALTER TABLE repository_class_config_code
       ADD CONSTRAINT xpkrepository_class_config_code PRIMARY KEY (
              rccc_code)
go

CREATE TABLE repository_class_configuration (
       rpcc_value           nvarchar(20) NULL,
       rccc_code            nvarchar(20) NOT NULL,
       repc_system_name     nvarchar(20) NOT NULL
)
go

CREATE INDEX xif1repository_class_configuration ON repository_class_configuration
(
       rccc_code
)
go

CREATE INDEX xif2repository_class_configuration ON repository_class_configuration
(
       repc_system_name
)
go

ALTER TABLE repository_class_configuration
       ADD CONSTRAINT xpkrepository_class_configuration PRIMARY KEY (
              rccc_code, repc_system_name)
go

CREATE TABLE repository_class_property (
       rpcp_system_name     nvarchar(20) NOT NULL,
       rpcp_display_name    nvarchar(255) NULL,
       rpcp_property_size   int NULL,
       rpcp_property_format nvarchar(255) NULL,
       rpcp_mandatory_flag  tinyint NULL,
       rpcp_multivalue_flag tinyint NULL,
       rpcp_property_xpath  nvarchar(255) NULL,
       rpcp_property_column_number tinyint NULL,
       rpcp_seq_num         int NULL,
       cpdc_code            nvarchar(20) NULL,
       repc_system_name     nvarchar(20) NOT NULL
)
go

CREATE INDEX xif2repository_class_property ON repository_class_property
(
       cpdc_code
)
go

CREATE INDEX xif3repository_class_property ON repository_class_property
(
       repc_system_name
)
go

ALTER TABLE repository_class_property
       ADD CONSTRAINT xpkrepository_class_property PRIMARY KEY (
              rpcp_system_name, repc_system_name)
go

CREATE TABLE repository_document (
       rdoc_id              int IDENTITY,
       rdoc_repository      nvarchar(255) NOT NULL,
       rdoc_repository_document_id nvarchar(255) NULL,
       rdoc_shortcut_url    nvarchar(255) NULL,
       rdoc_capture_user    nvarchar(255) NULL,
       rpty_code            nvarchar(10) NOT NULL,
       cdoc_document_key    nvarchar(255) NULL,
       rdty_code            nvarchar(20) NULL,
       rdoc_created_date    datetime NOT NULL,
       rdoc_source_name     nvarchar(255) NULL
)
go

CREATE INDEX xif1repository_document ON repository_document
(
       cdoc_document_key
)
go

CREATE INDEX xif2repository_document ON repository_document
(
       rdty_code
)
go

ALTER TABLE repository_document
       ADD CONSTRAINT xpkrepository_document PRIMARY KEY (rdoc_id)
go

CREATE TABLE repository_document_type_code (
       rdty_code            nvarchar(20) NOT NULL,
       rdty_name            nvarchar(50) NOT NULL
)
go

ALTER TABLE repository_document_type_code
       ADD CONSTRAINT xpkrepository_document_type_code PRIMARY KEY (
              rdty_code)
go

CREATE TABLE component_type_code (
       comt_code            nvarchar(20) NOT NULL,
       comt_name            nvarchar(50) NOT NULL
)
go

ALTER TABLE component_type_code
       ADD CONSTRAINT xpkcomponent_type_code PRIMARY KEY (comt_code)
go

ALTER TABLE captured_document
       ADD CONSTRAINT r_cdst_cdoc
              FOREIGN KEY (cdst_code)
                             REFERENCES captured_document_state_code  (
              cdst_code)
go

ALTER TABLE captured_document
       ADD CONSTRAINT r_cdoc_dupc
              FOREIGN KEY (dupc_id)
                             REFERENCES duplicate_criteria  (dupc_id)
go

ALTER TABLE repository_document
       ADD CONSTRAINT r_rdoc_cdoc
              FOREIGN KEY (cdoc_document_key)
                             REFERENCES captured_document  (
              cdoc_document_key)
go

ALTER TABLE repository_class_property
       ADD CONSTRAINT r_cpdc_rpcp
              FOREIGN KEY (cpdc_code)
                             REFERENCES class_property_data_type_code  (
              cpdc_code)
go

ALTER TABLE duplicate_criteria_fields
       ADD CONSTRAINT r_dpcf_dupc
              FOREIGN KEY (dupc_id)
                             REFERENCES duplicate_criteria  (dupc_id)
go

ALTER TABLE repository_class
       ADD CONSTRAINT r_repo_repc
              FOREIGN KEY (repo_id)
                             REFERENCES repository  (repo_id)
go

ALTER TABLE repository_class_configuration
       ADD CONSTRAINT r_repc_rpcc
              FOREIGN KEY (repc_system_name)
                             REFERENCES repository_class  (
              repc_system_name)
go

ALTER TABLE repository_class_configuration
       ADD CONSTRAINT r_rccc_rpcc
              FOREIGN KEY (rccc_code)
                             REFERENCES repository_class_config_code  (
              rccc_code)
go

ALTER TABLE repository_class_property
       ADD CONSTRAINT r_repc_rpcp
              FOREIGN KEY (repc_system_name)
                             REFERENCES repository_class  (
              repc_system_name)
go

ALTER TABLE repository_document
       ADD CONSTRAINT r_rdty_rdoc
              FOREIGN KEY (rdty_code)
                             REFERENCES repository_document_type_code  (
              rdty_code)
go

ALTER TABLE archive_server ADD
aprf_id int NULL,
comp_code nvarchar (10) NULL
GO

CREATE NONCLUSTERED INDEX xif4archive_server ON archive_server (aprf_id)
CREATE NONCLUSTERED INDEX xif5archive_server ON archive_server (comp_code)
GO

ALTER TABLE archive_server ADD
CONSTRAINT r_aprf_asvr FOREIGN KEY (aprf_id) REFERENCES archive_profile (aprf_id),
CONSTRAINT r_comp_asvr FOREIGN KEY (comp_code) REFERENCES component (comp_code)
GO

alter table component add comp_local_interface varchar(255) NULL
alter table component add comp_remote_interface varchar(255) NULL
alter table component add invt_code nvarchar(20) NULL 
alter table component add comt_code nvarchar(20) NULL 
alter table component add dcty_code nvarchar(10) NULL

CREATE INDEX xif1component ON component
(
       invt_code
)
go

CREATE INDEX xif2component ON component
(
       comt_code
)
go

CREATE INDEX xif3component ON component
(
       dcty_code
)
go

ALTER TABLE component
       ADD CONSTRAINT r_dcty_comp
              FOREIGN KEY (dcty_code)
                             REFERENCES document_type  (dcty_code)
go

ALTER TABLE component
       ADD CONSTRAINT r_comt_comp
              FOREIGN KEY (comt_code)
                             REFERENCES component_type_code  (
              comt_code)
go

ALTER TABLE component
       ADD CONSTRAINT r_invt_comp
              FOREIGN KEY (invt_code)
                             REFERENCES invocation_type_code  (
              invt_code)
go

ALTER TABLE component_extended_value ADD
docp_code nvarchar (10)  NULL,
dcty_code nvarchar (10)  NULL
GO

CREATE NONCLUSTERED INDEX xif5component_extended_value ON component_extended_value (docp_code, dcty_code)

ALTER TABLE component_extended_value ADD
CONSTRAINT r_docp_cexv FOREIGN KEY (docp_code, dcty_code) REFERENCES document_property (docp_code, dcty_code)
GO

alter table document_property add docp_avail_for_audit tinyint NULL
alter table document_property add docp_avail_for_dup tinyint NULL

ALTER TABLE expression_value ADD eval_regexp_replace_mode_flag tinyint NULL
GO

ALTER TABLE filter_rule_monitored_location DROP
CONSTRAINT r_aprf_frml,
CONSTRAINT r_asvr_frml
GO

DROP INDEX filter_rule_monitored_location.xif3filter_rule_monitored_location
GO

DROP INDEX filter_rule_monitored_location.xif4filter_rule_monitored_location
GO

ALTER TABLE filter_rule_monitored_location ADD
source_asvr_id int NULL

ALTER TABLE filter_rule_monitored_location ADD
target_asvr_id int NULL	

CREATE NONCLUSTERED INDEX xif4filter_rule_monitored_location ON filter_rule_monitored_location (source_asvr_id)
CREATE NONCLUSTERED INDEX xif5filter_rule_monitored_location ON filter_rule_monitored_location (target_asvr_id)
GO

ALTER TABLE filter_rule_monitored_location ADD
CONSTRAINT r_asvr_frml FOREIGN KEY (source_asvr_id) REFERENCES archive_server (asvr_id),
CONSTRAINT r_asvr_frml_target FOREIGN KEY (target_asvr_id) REFERENCES archive_server (asvr_id)
go

ALTER TABLE monitored_location ADD
mloc_options nvarchar (255) NULL
go

ALTER TABLE monitored_location ALTER COLUMN mloc_physical_loc nvarchar (1000)  NULL
ALTER TABLE monitored_location ALTER COLUMN mloc_loc_name nvarchar (1000) NULL
go

insert into archive_server_type (asty_code,asty_name) values ( N'PST_LOC',N'PST Profile')
insert into archive_server_type (asty_code,asty_name) values ( N'PST_PARSER',N'PST Profile')
go

insert into client_config_option_code (ccoc_code,rpty_code,ccoc_name,vldt_code,ccoc_has_default_value_flag) values ( N'ADVSH_ON',N'P8_CE',N'Config: Shortcuts: Enable client shortcut integration',N'CHECKBOX',0)
insert into client_config_option_code (ccoc_code,rpty_code,ccoc_name,vldt_code,ccoc_has_default_value_flag) values ( N'ADVSH_WS',N'P8_CE',N'Config: Shortcuts: Retrieve email via Web Services',N'CHECKBOX',0)

insert into client_config_option_code (ccoc_code,rpty_code,ccoc_name,vldt_code,ccoc_has_default_value_flag) 
select N'SENT_PROMP',rpty_code,N'Screen: eMgr Config: Enable prompt to capture sent items',N'CHECKBOX',0
from client_config_option_code
where ccoc_code = 'ADDBYGROUP'

insert into client_config_option_code (ccoc_code,rpty_code,ccoc_name,vldt_code,ccoc_has_default_value_flag) 
select N'DUP_ENABLE',rpty_code,N'Config: Duplicates: Enable Duplicate checking',N'CHECKBOX',0
from client_config_option_code
where ccoc_code = 'ADDBYGROUP'

insert into client_config_option_code (ccoc_code,rpty_code,ccoc_name,vldt_code,ccoc_has_default_value_flag) 
select N'DUP_BYPASS',rpty_code,N'Config: Duplicates: Allow users to bypass duplicate check',N'CHECKBOX',0
from client_config_option_code
where ccoc_code = 'ADDBYGROUP'

update client_config_option_code set ccoc_name=N'Screen: eMgr Config: Select default profile.' where ccoc_code=N'SELDEFPRF'
go

insert into client_config_option (ccoc_code,rpty_code,ccop_default_value,asvr_id,ccop_avail_to_client_flag) values ( N'ADVSH_ON',N'P8_CE',N'0',1,0)
insert into client_config_option (ccoc_code,rpty_code,ccop_default_value,asvr_id,ccop_avail_to_client_flag) values ( N'ADVSH_WS',N'P8_CE',N'0',1,0)
insert into client_config_option (ccoc_code,rpty_code,ccop_default_value,asvr_id,ccop_avail_to_client_flag) values ( N'SENT_PROMP',N'P8_CE',N'0',1,1)
insert into client_config_option (ccoc_code,rpty_code,ccop_default_value,asvr_id,ccop_avail_to_client_flag) values ( N'DUP_ENABLE',N'P8_CE',N'0',1,0)
insert into client_config_option (ccoc_code,rpty_code,ccop_default_value,asvr_id,ccop_avail_to_client_flag) values ( N'DUP_BYPASS',N'P8_CE',N'0',1,0)
go

insert into document_type (dcty_code,dcty_name) values ( N'PST_LOC',N'PST Locator')
insert into document_type (dcty_code,dcty_name) values ( N'PST_PARSER',N'PST Parser')
go

UPDATE document_property SET docp_metadata_path=N'.//text()', docp_utc_flag=0, docp_avail_for_audit=0, docp_avail_for_dup=0 WHERE docp_code=N'ALL' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_metadata_path=N'/email_metadata/altered/text()', docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'ALTERED' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=1 WHERE docp_code=N'ATTACH_FLG' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=0, docp_avail_for_dup=0 WHERE docp_code=N'BCC_ADDR' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=0, docp_avail_for_dup=0 WHERE docp_code=N'BCC_ALL' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=0, docp_avail_for_dup=0 WHERE docp_code=N'BCC_DISP' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_metadata_path=N'/email_metadata/bcc_dom/value/text()', docp_utc_flag=0, docp_avail_for_audit=0, docp_avail_for_dup=0 WHERE docp_code=N'BCC_DOM' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=1 WHERE docp_code=N'BODY' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'BODY_SUM' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_metadata_path=N'/email_metadata/captured/text()', docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'CAPTURED' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'CC_ADDR' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'CC_ALL' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'CC_DISP' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_metadata_path=N'/email_metadata/cc_dom/value/text()', docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'CC_DOM' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'CONV_TOPIC' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=0, docp_avail_for_dup=0 WHERE docp_code=N'DOC_TITLE' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_name=N'CC Address User ID', docp_avail_for_profiles=1, docp_avail_for_rules=1, docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'EMAIL_CC' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_name=N'From Address User ID', docp_avail_for_profiles=1, docp_avail_for_rules=1, docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'EMAIL_FROM' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=1 WHERE docp_code=N'EMAIL_ID' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_name=N'To Address User ID', docp_avail_for_profiles=1, docp_avail_for_rules=1, docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'EMAIL_TO' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_metadata_path=N'/email_metadata/file_size/text()', docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=1 WHERE docp_code=N'FILE_SIZE' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'FROM_ADDR' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'FROM_ALL' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'FROM_DISP' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_metadata_path=N'/email_metadata/from_dom/value/text()', docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'FROM_DOM' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'PATH' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_name=N'Profle ID', docp_metadata_path=N'/email_metadata/profile_id/text()', docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'PROFILEID' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_data_format=N'MM\/dd\/yyyy HH\:mm\:ss', docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'REC_DTLOC' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_data_format=N'MM\/dd\/yyyy HH\:mm\:ss', docp_utc_flag=1, docp_avail_for_audit=1, docp_avail_for_dup=1 WHERE docp_code=N'REC_DTUTC' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=0, docp_avail_for_dup=0 WHERE docp_code=N'RETURN_VAL' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_data_format=N'MM\/dd\/yyyy HH\:mm\:ss', docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'SENT_DTLOC' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_data_format=N'MM\/dd\/yyyy HH\:mm\:ss', docp_utc_flag=1, docp_avail_for_audit=1, docp_avail_for_dup=1 WHERE docp_code=N'SENT_DTUTC' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=1 WHERE docp_code=N'SUBJECT' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'TARGET' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'TO_ADDR' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'TO_ALL' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'TO_DISP' AND dcty_code=N'EXCH_EMAIL'
UPDATE document_property SET docp_metadata_path=N'/email_metadata/to_dom/value/text()', docp_utc_flag=0, docp_avail_for_audit=1, docp_avail_for_dup=0 WHERE docp_code=N'TO_DOM' AND dcty_code=N'EXCH_EMAIL'
go

INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'ACCESS_LOC', N'PST_LOC', N'(File) Last Accessed Date (Local)', 0, N'DATETIME', 1, 1, N'/ytg_filesystem_metadata/access_dtloc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'ACCESS_UTC', N'PST_LOC', N'(File) Last Accessed Date (UTC)', 0, N'DATETIME', 1, 1, N'/ytg_filesystem_metadata/access_dtutc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 1, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'ALL', N'PST_PARSER', N'All Properties', 0, N'STRING', 0, 1, N'.//text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'ALTERED', N'PST_PARSER', N'Item Altered', 0, N'STRING', 0, 1, N'/email_metadata/altered/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'ARCHIVED', N'PST_LOC', N'(File) Archived Flag', 0, N'STRING', 1, 1, N'/ytg_filesystem_metadata/archived/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'ATT_COUNT', N'EXCH_EMAIL', N'Attachment Count', 0, N'STRING', 1, 1, N'/email_metadata/att_count/text()', 0, NULL, NULL, 0, 1, 1)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'ATTACH_FLG', N'PST_PARSER', N'Attachment Flag', 0, N'STRING', 1, 1, N'/email_metadata/attach_flg/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'BASE_FILE', N'PST_LOC', N'(File) Base File Name', 0, N'STRING', 1, 1, N'/ytg_filesystem_metadata/basefilename/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'BCC_ADDR', N'PST_PARSER', N'BCC Address', 0, N'STRING', 1, 1, N'/email_metadata/bcc_addr/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'BCC_ALL', N'PST_PARSER', N'BCC Address/Display', 0, N'STRING', 1, 0, N'/email_metadata/bcc_all/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'BCC_DISP', N'PST_PARSER', N'BCC Display', 0, N'STRING', 1, 1, N'/email_metadata/bcc_disp/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'BCC_DOM', N'PST_PARSER', N'BCC Address Domain', 0, N'STRING', 0, 1, N'/email_metadata/bcc_dom/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'BODY', N'PST_PARSER', N'Body', 0, N'STRING', 0, 1, N'/email_metadata/body/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'BODY_SUM', N'PST_PARSER', N'Body Summary', 0, N'STRING', 1, 0, N'/email_metadata/body_sum/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CAP_DTLOC', N'EXCH_EMAIL', N'Captured Date (Local)', 0, N'DATETIME', 0, 1, N'/email_metadata/cap_dtloc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CAP_DTLOC', N'PST_PARSER', N'Captured Date (Local)', 0, N'DATETIME', 0, 1, N'/email_metadata/cap_dtloc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CAP_DTUTC', N'EXCH_EMAIL', N'Captured Date (UTC)', 0, N'DATETIME', 1, 1, N'/email_metadata/cap_dtutc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 1, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CAP_DTUTC', N'PST_PARSER', N'Captured Date (UTC)', 0, N'DATETIME', 1, 1, N'/email_metadata/cap_dtutc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 1, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CAP_FLAG', N'PST_LOC', N'(File) Already Captured', 0, N'STRING', 1, 1, N'/ytg_filesystem_metadata/captured_flag/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CAPTURED', N'PST_PARSER', N'Item Already Captured', 0, N'STRING', 0, 1, N'/email_metadata/captured/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CC_ADDR', N'PST_PARSER', N'CC Address', 0, N'STRING', 1, 1, N'/email_metadata/cc_addr/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CC_ALL', N'PST_PARSER', N'CC Address/Display', 0, N'STRING', 1, 0, N'/email_metadata/cc_all/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CC_DISP', N'PST_PARSER', N'CC Display', 0, N'STRING', 1, 1, N'/email_metadata/cc_disp/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CC_DOM', N'PST_PARSER', N'CC Address Domain', 0, N'STRING', 0, 1, N'/email_metadata/cc_dom/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CC_RAW', N'EXCH_EMAIL', N'CC Address (Unresolved)', 0, N'STRING', 0, 0, N'/email_metadata/cc_raw/value/text()', 0, NULL, NULL, 0, 1, 1)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CC_RAW', N'PST_PARSER', N'CC Address (Unresolved)', 0, N'STRING', 0, 0, N'/email_metadata/cc_raw/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'COMPRESSED', N'PST_LOC', N'(File) Compressed Flag', 0, N'STRING', 1, 1, N'/ytg_filesystem_metadata/compressed/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CONV_TOPIC', N'PST_PARSER', N'Conversation Topic', 0, N'STRING', 1, 1, N'/email_metadata/conv_topic/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CREATE_LOC', N'PST_LOC', N'(File) Created Date (Local)', 0, N'DATETIME', 1, 1, N'/ytg_filesystem_metadata/create_dtloc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'CREATE_UTC', N'PST_LOC', N'(File) Created Date (UTC)', 0, N'DATETIME', 1, 1, N'/ytg_filesystem_metadata/create_dtutc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 1, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'DBPATH', N'EXCH_EMAIL', N'Lotus Database Path', 0, N'STRING', 0, 0, N'/email_metadata/db_path/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'DBTITLE', N'EXCH_EMAIL', N'Lotus Database Title', 0, N'STRING', 0, 0, N'/email_metadata/db_title/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'DOC_TITLE', N'PST_PARSER', N'Document Title', 0, N'STRING', 0, 0, N'/email_metadata/document_title/text()', 3, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'DUP_FLAG', N'EXCH_EMAIL', N'Duplicate Item Flag', 0, N'STRING', 1, 1, N'/email_metadata/dup_flag/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'DUP_KEY', N'EXCH_EMAIL', N'Duplicate Key', 0, N'STRING', 1, 1, N'/email_metadata/dup_key/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'EMAIL_BCC', N'EXCH_EMAIL', N'BCC Address User ID', 1, N'STRING', 1, 1, N'/email_metadata/email_bcc/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'EMAIL_BCC', N'PST_PARSER', N'BCC Address User ID', 1, N'STRING', 1, 1, N'/email_metadata/email_bcc/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'EMAIL_CC', N'PST_PARSER', N'CC Address User ID', 1, N'STRING', 1, 1, N'/email_metadata/email_cc/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'EMAIL_FROM', N'PST_PARSER', N'From Address User ID', 1, N'STRING', 1, 1, N'/email_metadata/email_from/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'EMAIL_ID', N'PST_PARSER', N'Email Id', 0, N'STRING', 1, 0, N'/email_metadata/email_id/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'EMAIL_TO', N'PST_PARSER', N'To Address User ID', 1, N'STRING', 1, 1, N'/email_metadata/email_to/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'EMAIL_UNID', N'EXCH_EMAIL', N'Lotus UNID', 0, N'STRING', 0, 0, N'/email_metadata/email_unid/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'EML_SERVER', N'EXCH_EMAIL', N'Email Server', 0, N'STRING', 1, 1, N'/email_metadata/email_server/text()', 0, NULL, NULL, 0, 1, 1)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'ENCRYPTED', N'PST_LOC', N'(File) Encrypted Flag', 0, N'STRING', 1, 1, N'/ytg_filesystem_metadata/encrypted/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'EXCH_SVR', N'PST_PARSER', N'Exchange Server Name', 0, N'STRING', 0, 0, N'/ytg_metadata/exchange_server_name/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'FILE_SIZE', N'PST_PARSER', N'File Size', 0, N'FILESIZE', 0, 1, N'/email_metadata/file_size/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'FILENAME', N'PST_LOC', N'(File) File Name', 0, N'STRING', 1, 1, N'/ytg_filesystem_metadata/filename/text()', 1, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'FILESIZE', N'PST_LOC', N'(File) File Size (KB)', 0, N'FILESIZE', 1, 1, N'/ytg_filesystem_metadata/filesize/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'FORM', N'EXCH_EMAIL', N'Message Class', 0, N'STRING', 1, 1, N'/email_metadata/form/text()', 0, NULL, NULL, 0, 1, 1)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'FORM', N'PST_PARSER', N'Message Class', 0, N'STRING', 1, 1, N'/email_metadata/form/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'FROM_ADDR', N'PST_PARSER', N'From Address', 0, N'STRING', 1, 1, N'/email_metadata/from_addr/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'FROM_ALL', N'PST_PARSER', N'From Address/Display', 0, N'STRING', 1, 0, N'/email_metadata/from_all/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'FROM_DISP', N'PST_PARSER', N'From Display', 0, N'STRING', 1, 1, N'/email_metadata/from_disp/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'FROM_DOM', N'PST_PARSER', N'From Address Domain', 0, N'STRING', 0, 1, N'/email_metadata/from_dom/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'FROM_RAW', N'EXCH_EMAIL', N'From Address (Unresolved)', 0, N'STRING', 0, 0, N'/email_metadata/from_raw/value/text()', 0, NULL, NULL, 0, 1, 1)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'FROM_RAW', N'PST_PARSER', N'From Address (Unresolved)', 0, N'STRING', 0, 0, N'/email_metadata/from_raw/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'FULLPATH', N'PST_LOC', N'(File) Full Path', 0, N'STRING', 1, 1, N'/ytg_filesystem_metadata/fullpath/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'HIDDEN', N'PST_LOC', N'(File) Hidden Flag', 0, N'STRING', 1, 1, N'/ytg_filesystem_metadata/hidden/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'MAINDOC', N'PST_LOC', N'Main Document Flag', 0, N'STRING', 0, 0, N'/ytg_metadata/maindocument/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'MODIFY_LOC', N'PST_LOC', N'(File) Modified Date (Local)', 0, N'DATETIME', 1, 1, N'/ytg_filesystem_metadata/modify_dtloc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'MODIFY_UTC', N'PST_LOC', N'(File) Modified Date (UTC)', 0, N'DATETIME', 1, 1, N'/ytg_filesystem_metadata/modify_dtutc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 1, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'ORIG_USER', N'EXCH_EMAIL', N'Originating User ID', 0, N'STRING', 1, 1, N'/email_metadata/orig_user/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'OUTLOOKPRF', N'PST_LOC', N'Outlook Profile Name', 0, N'STRING', 0, 0, N'/ytg_metadata/outlook_profile_name/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'OWNER', N'PST_LOC', N'Owner', 0, N'STRING', 0, 0, N'/ytg_metadata/owner/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'OWNER_GRP', N'PST_LOC', N'Owner Group', 0, N'STRING', 0, 0, N'/ytg_metadata/owner_group/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'P8_DOCURI', N'PST_LOC', N'P8 External Reference Document Location', 0, N'STRING', 0, 0, N'/ytg_metadata/p8po_docuri/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'P8_MIMETY', N'PST_LOC', N'P8 External Reference Mime Type', 0, N'STRING', 0, 0, N'/ytg_metadata/p8po_mimetype/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'PATH', N'PST_LOC', N'(File) Path', 0, N'STRING', 1, 1, N'/ytg_filesystem_metadata/path/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'PATH', N'PST_PARSER', N'Email Folder Path', 0, N'STRING', 1, 1, N'/email_metadata/path/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'PROC_FLAG', N'PST_LOC', N'(File) Already Processed', 0, N'STRING', 1, 1, N'/ytg_filesystem_metadata/processed_flag/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'PROCESSED', N'PST_LOC', N'Processed Flag', 0, N'STRING', 0, 0, N'/ytg_metadata/processed_flag/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'PROFILEID', N'PST_PARSER', N'Profle ID', 0, N'STRING', 0, 0, N'/email_metadata/profile_id/text()', 2, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'PST_USER', N'PST_LOC', N'PST User', 0, N'STRING', 0, 0, N'/ytg_metadata/pst_user/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'READONLY', N'PST_LOC', N'(File) Read Only', 0, N'STRING', 1, 1, N'/ytg_filesystem_metadata/readonly/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'REC_DTLOC', N'PST_PARSER', N'Received Date (Local)', 0, N'DATETIME', 0, 1, N'/email_metadata/rec_dtloc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'REC_DTUTC', N'PST_PARSER', N'Received Date (UTC)', 0, N'DATETIME', 1, 1, N'/email_metadata/rec_dtutc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 1, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'RETURN_VAL', N'PST_LOC', N'Rule Return Value', 0, N'STRING', 1, 1, N'/ytg_metadata/returnval/text()', 0, NULL, NULL, 0, 1, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'RETURN_VAL', N'PST_PARSER', N'Rule Return Value', 0, N'STRING', 1, 0, N'/email_metadata/return_val/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'SENT_DTLOC', N'PST_PARSER', N'Sent Date (Local)', 0, N'DATETIME', 0, 1, N'/email_metadata/sent_dtloc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'SENT_DTUTC', N'PST_PARSER', N'Sent Date (UTC)', 0, N'DATETIME', 1, 1, N'/email_metadata/sent_dtutc/text()', 0, N'MM\/dd\/yyyy HH\:mm\:ss', NULL, 1, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'SUBJECT', N'PST_PARSER', N'Subject', 0, N'STRING', 1, 1, N'/email_metadata/subject/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'TARGET', N'PST_PARSER', N'Target File', 0, N'STRING', 0, 0, N'//file/text()', 1, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'TO_ADDR', N'PST_PARSER', N'To Address', 0, N'STRING', 1, 1, N'/email_metadata/to_addr/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'TO_ALL', N'PST_PARSER', N'To Address/Display', 0, N'STRING', 1, 0, N'/email_metadata/to_all/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'TO_DISP', N'PST_PARSER', N'To Display', 0, N'STRING', 1, 1, N'/email_metadata/to_disp/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'TO_DOM', N'PST_PARSER', N'To Address Domain', 0, N'STRING', 0, 1, N'/email_metadata/to_dom/value/text()', 0, NULL, NULL, 0, 0, 0)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'TO_RAW', N'EXCH_EMAIL', N'To Address (Unresolved)', 0, N'STRING', 0, 0, N'/email_metadata/to_raw/value/text()', 0, NULL, NULL, 0, 1, 1)
INSERT INTO document_property (docp_code, dcty_code, docp_name, docp_avail_for_security_flag, dcdt_code, docp_avail_for_profiles, docp_avail_for_rules, docp_metadata_path, docp_metadata_usage, docp_data_format, docp_column_number, docp_utc_flag, docp_avail_for_audit, docp_avail_for_dup) VALUES (N'TO_RAW', N'PST_PARSER', N'To Address (Unresolved)', 0, N'STRING', 0, 0, N'/email_metadata/to_raw/value/text()', 0, NULL, NULL, 0, 0, 0)
go

insert into repository_type (rpty_code,rpty_name) values ( N'FILESYSTEM',N'File System')
go

INSERT INTO repository_archive_option_code (rocd_code, rpty_code, rocd_name) VALUES (N'CREATEFLD', N'FILENET_CS', N'Create Folder')
INSERT INTO repository_archive_option_code (rocd_code, rpty_code, rocd_name) VALUES (N'CREATEFLD', N'FILENET_IS', N'Create Folder')
INSERT INTO repository_archive_option_code (rocd_code, rpty_code, rocd_name) VALUES (N'DOCLASS', N'FILESYSTEM', N'Document Class')
INSERT INTO repository_archive_option_code (rocd_code, rpty_code, rocd_name) VALUES (N'FILEHIDDEN', N'FILESYSTEM', N'File Hidden')
INSERT INTO repository_archive_option_code (rocd_code, rpty_code, rocd_name) VALUES (N'FILEREADON', N'FILESYSTEM', N'File Read Only')
INSERT INTO repository_archive_option_code (rocd_code, rpty_code, rocd_name) VALUES (N'FOLDERFILE', N'FILESYSTEM', N'Files Folder')
INSERT INTO repository_archive_option_code (rocd_code, rpty_code, rocd_name) VALUES (N'FOLDERINDX', N'FILESYSTEM', N'Folder Index')
INSERT INTO repository_archive_option_code (rocd_code, rpty_code, rocd_name) VALUES (N'INDXHIDDEN', N'FILESYSTEM', N'Index Hidden')
INSERT INTO repository_archive_option_code (rocd_code, rpty_code, rocd_name) VALUES (N'INDXREADON', N'FILESYSTEM', N'Index Read Only')
INSERT INTO repository_archive_option_code (rocd_code, rpty_code, rocd_name) VALUES (N'MINORVER', N'P8_CE', N'Minor Version')
go

insert into repository_object_type (roty_code,rpty_code,roty_name) values ( N'User',N'FILESYSTEM',N'User')
insert into repository_object_type (roty_code,rpty_code,roty_name) values ( N'Group',N'FILESYSTEM',N'Group')
go

insert into repository_property_class (rcls_code,rpty_code,rcls_name) values ( N'ITEM',N'FILESYSTEM',N'Item')
go

insert into repository_property_data_type (rpty_code,rpdt_code,rpdt_name) values ( N'FILESYSTEM',N'idmTypeString',N'String')
insert into repository_property_data_type (rpty_code,rpdt_code,rpdt_name) values ( N'FILESYSTEM',N'idmTypeDate',N'Date/Time')
insert into repository_property_data_type (rpty_code,rpdt_code,rpdt_name) values ( N'FILESYSTEM',N'idmTypeLong',N'Integer')
go

SET DATEFORMAT ymd
delete from schema_version
insert into schema_version (sver_major_version,sver_minor_version,sver_revision_version,sver_comment,sver_version_date) values ( 15,0,0,N'5.2','05/12/19')
go

insert into security_level_type (slty_code,rpty_code,slty_name,slty_avail_to_client_flag) values ( N'ACC_MASK',N'FILESYSTEM',N'Access Mask',0)
go

insert into source_server_type (ssty_code,ssty_name) values ( N'PST_LOC',N'PST Locator')
insert into source_server_type (ssty_code,ssty_name) values ( N'PST_PARSER',N'PST Parser')
go

insert into location_type (lcty_code,ssty_code,lcty_name) values ( N'BASE',N'FILESYSTEM',N'Base Location')
insert into location_type (lcty_code,ssty_code,lcty_name) values ( N'FOLDER',N'FILESYSTEM',N'Folder')
insert into location_type (lcty_code,ssty_code,lcty_name) values ( N'SUBFLDR',N'FILESYSTEM',N'Subfolder')
insert into location_type (lcty_code,ssty_code,lcty_name) values ( N'FOLDER',N'PST_LOC',N'Folder')
insert into location_type (lcty_code,ssty_code,lcty_name) values ( N'SUBFLDR',N'PST_LOC',N'Subfolder')
insert into location_type (lcty_code,ssty_code,lcty_name) values ( N'COMPUTER',N'PST_LOC',N'Computer')
insert into location_type (lcty_code,ssty_code,lcty_name) values ( N'SELECT',N'LOTUS',N'Lotus Template')
insert into location_type (lcty_code,ssty_code,lcty_name) values ( N'BASE',N'PST_LOC',N'Base Location')
insert into location_type (lcty_code,ssty_code,lcty_name) values ( N'COMP_GRP',N'PST_LOC',N'Computer Group')
go

insert into connection_parameter_code (rpty_code,cpcd_code,cpcd_name,cdty_code) values ( N'FILESYSTEM',N'INDEXOPT',N'Index file option',N'STRING')
insert into connection_parameter_code (rpty_code,cpcd_code,cpcd_name,cdty_code) values ( N'FILESYSTEM',N'LINKURL',N'FS URL',N'STRING')
insert into connection_parameter_code (rpty_code,cpcd_code,cpcd_name,cdty_code) values ( N'FILESYSTEM',N'LINKTYPE',N'FS Doc Link Type',N'STRING')
go

insert into invocation_type_code (invt_code,invt_name) values ( N'LOCAL',N'Local')
insert into invocation_type_code (invt_code,invt_name) values ( N'REMOTE',N'Remote')
insert into component_type_code (comt_code,comt_name) values ( N'SOURCE',N'Source Server')
insert into component_type_code (comt_code,comt_name) values ( N'PARSER',N'Parser')
insert into component_type_code (comt_code,comt_name) values ( N'RENDERER',N'Renderer')
insert into component_type_code (comt_code,comt_name) values ( N'CAPTURE',N'Capture')
go

insert into component (comp_code,comp_name,comp_local_interface,comp_remote_interface,invt_code,comt_code,dcty_code) values ( N'FS_CONN',N'File System Connector',NULL,NULL,N'LOCAL',N'SOURCE',NULL)
insert into component (comp_code,comp_name,comp_local_interface,comp_remote_interface,invt_code,comt_code,dcty_code) values ( N'PST_LOC',N'PST Locator',NULL,NULL,N'LOCAL',N'SOURCE',NULL)
insert into component (comp_code,comp_name,comp_local_interface,comp_remote_interface,invt_code,comt_code,dcty_code) values ( N'PST_PARSER',N'PST Parser',N'PSTParser',NULL,N'LOCAL',N'PARSER',NULL)
insert into component (comp_code,comp_name,comp_local_interface,comp_remote_interface,invt_code,comt_code,dcty_code) values ( N'TIFF',N'TIFF Renderer',N'DocConv',N'tcp://localhost:14562/DocumentConversion',N'REMOTE',N'RENDERER',NULL)
insert into component (comp_code,comp_name,comp_local_interface,comp_remote_interface,invt_code,comt_code,dcty_code) values ( N'RETENTION',N'File Retention',N'retention',NULL,N'LOCAL',N'RENDERER',NULL)
UPDATE component SET invt_code=N'LOCAL', comt_code=N'SOURCE' WHERE comp_code=N'ECW_WS_CS'
UPDATE component SET invt_code=N'LOCAL', comt_code=N'SOURCE' WHERE comp_code=N'ECW_WS_P8'
UPDATE component SET invt_code=N'LOCAL', comt_code=N'SOURCE', dcty_code=N'EXCH_EMAIL' WHERE comp_code=N'EXCH_CONN'
UPDATE component SET invt_code=N'LOCAL', comt_code=N'SOURCE', dcty_code=N'EXCH_EMAIL' WHERE comp_code=N'LOTUS_CONN'
UPDATE component SET invt_code=N'LOCAL', comt_code=N'SOURCE' WHERE comp_code=N'SYSTEM'
UPDATE component SET comp_local_interface='Capture', comp_remote_interface='tcp://localhost:14561/UniversalFileImporter', invt_code=N'REMOTE', comt_code=N'CAPTURE' WHERE comp_code=N'UFI'
go

INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'AUDIT_LOG_ENABLE', N'Enable Audit Log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'AUDIT_LOG_FIELDS', N'Fields to include in audit log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'AUDIT_LOG_FOLDER', N'Audit Log Folder')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'AUDIT_LOG_MAX_SIZE', N'Maximum audit log file size')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'AUDIT_LOG_PER_PROFILE', N'Create per-Profile audit log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'DUP_DB_LOCATION', N'Duplicate Database Location Type')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'DUP_DB_NAME', N'Duplicate Database Name')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'DUP_DB_PASS', N'Duplciate Database User Password')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'DUP_DB_SERVER', N'Duplicate Database Server')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'DUP_DB_USER', N'Duplicate Database User')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'DUP_ENABLE', N'Enable Duplicate Detection')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'DUP_ENABLE_CHECK', N'Enable Duplicate Check')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'DUP_EXPIRY_TIME', N'Duplicate Entry Expirty Time')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'DUP_PROFILE_OPTIONS', N'Duplicate Check Options')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'IGNORE_ACCESS_DENIED', N'Ignore if access denied')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'IGNORE_CAPTURED', N'Ignore captured items')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'IGNORE_PROCESSED', N'Ignore item processed by other profile')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'IGNORE_PROCESSED_CURRENT', N'Ignore item processed by current profile')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'POST_ERROR_ACTION', N'Post Processing action if error occurs')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'POST_ERROR_ACTION_VAL', N'Post Processing action value if error occurs')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'POST_ERROR_OVER', N'Override default settings (error file handling)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'POST_TARGET_ACTION', N'Post Processing Target Action')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'POST_TARGET_NR_ACT', N'Post Processing Target No Rule Action')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'POST_TARGET_NR_OVER', N'Override default settings (target file not captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'POST_TARGET_OVER', N'Override default settings (target file captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'SCHED_DETAIL', N'Scheduling details')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'SCHED_END', N'Scheduled task duration')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'SCHED_OVER', N'Override default scheduling settings')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'SCHED_STARTTIME', N'Scheduled task start time')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'EXCH_CONN', N'SCHED_TYPE', N'Schedule type')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'AUDIT_LOG_ENABLE', N'Enable Audit Log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'AUDIT_LOG_FIELDS', N'Fields to include in audit log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'AUDIT_LOG_FOLDER', N'Audit Log Folder')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'AUDIT_LOG_MAX_SIZE', N'Maximum audit log file size')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'AUDIT_LOG_PER_PROFILE', N'Create per-Profile audit log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'DERIVED_FN_FORMAT_STR', N'Regex format string')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'DERIVED_FN_REGEX', N'Regex for derived filename')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'DERIVED_FN_TYPE', N'How to derive filename')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'ENABLE_NOT', N'Enable Notifications')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'FILE_WAIT_DELAY', N'File Wait Delay')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'GET_ITID_FROM_METADATA', N'Get id from metadata')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'HAS_METADATA_FILE', N'Has metadata file')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'IGNORE_ACCESS_DENIED', N'Ignore if access denied')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'IGNORE_CAPTURED', N'Ignore captured items')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'IGNORE_PROCESSED', N'Ignore processed item')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'METADATA_FORMAT', N'Metadata File Format')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'MONITOR_FOR', N'What to monitor for')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'P8PO_DOCURI', N'Document URI')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'P8PO_MIMETYPE', N'Mime Type')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'POST_ERROR_ACTION', N'Post Processing action if error occurs')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'POST_ERROR_OVER', N'Override default settings (error file handling)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'POST_METADATA_ACTION', N'Post Processing Metadata File')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'POST_METADATA_NR_ACT_VAL', N'Post Processing Metdata No Rule Action Value')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'POST_METADATA_NR_OVER', N'Override default settings (metadata file not captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'POST_METADATA_NR_SAME_DOC', N'Use same post action as target no rule')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'POST_METADATA_OVER', N'Override default settings (metadata file captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'POST_METADATA_SAME_DOC', N'Use same post action as target')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'POST_TARGET_ACTION', N'Post Processing Target Action')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'POST_TARGET_NR_ACT', N'Post Processing Target No Rule Action')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'POST_TARGET_NR_OVER', N'Override default settings (target file not captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'POST_TARGET_OVER', N'Override default settings (target file captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'SCHED_DETAIL', N'Scheduling details')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'SCHED_END', N'Scheduled task duration')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'SCHED_OVER', N'Override default scheduling settings')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'SCHED_STARTTIME', N'Scheduled task start time')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'SCHED_TYPE', N'Schedule type')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'WATCH_FILTER', N'Watch filter')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'FS_CONN', N'WATCH_FILTER_TYPE', N'Watch filter type')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'AUDIT_LOG_ENABLE', N'Enable Audit Log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'AUDIT_LOG_FIELDS', N'Fields to include in audit log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'AUDIT_LOG_FOLDER', N'Audit Log Folder')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'AUDIT_LOG_MAX_SIZE', N'Maximum audit log file size')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'AUDIT_LOG_PER_PROFILE', N'Create per-Profile audit log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'DUP_DB_LOCATION', N'Duplicate Database Location Type')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'DUP_DB_NAME', N'Duplicate Database Name')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'DUP_DB_PASS', N'Duplciate Database User Password')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'DUP_DB_SERVER', N'Duplicate Database Server')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'DUP_DB_USER', N'Duplicate Database User')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'DUP_ENABLE', N'Enable Duplicate Detection')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'DUP_ENABLE_CHECK', N'Enable Duplicate Check')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'DUP_EXPIRY_TIME', N'Duplicate Entry Expirty Time')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'DUP_PROFILE_OPTIONS', N'Duplicate Check Options')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'IGNORE_ACCESS_DENIED', N'Ignore if access denied')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'IGNORE_CAPTURED', N'Ignore captured items')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'IGNORE_PROCESSED', N'Ignore item processed by other profile')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'IGNORE_PROCESSED_CURRENT', N'Ignore item processed by current profile')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'POST_ERROR_ACTION', N'Post Processing action if error occurs')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'POST_ERROR_ACTION_VAL', N'Post Processing action value if error occurs')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'POST_ERROR_OVER', N'Override default settings (error file handling)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'POST_TARGET_ACTION', N'Post Processing Target Action')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'POST_TARGET_NR_ACT', N'Post Processing Target No Rule Action')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'POST_TARGET_NR_OVER', N'Override default settings (target file not captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'POST_TARGET_OVER', N'Override default settings (target file captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'SCHED_DETAIL', N'Scheduling details')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'SCHED_END', N'Scheduled task duration')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'SCHED_OVER', N'Override default scheduling settings')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'SCHED_STARTTIME', N'Scheduled task start time')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'SCHED_TYPE', N'Schedule type')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'LOTUS_CONN', N'TIMESTAMP_ENABLE', N'Enable Timestamp Optimization')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'AUDIT_LOG_ENABLE', N'Enable Audit Log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'AUDIT_LOG_FIELDS', N'Fields to include in audit log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'AUDIT_LOG_FOLDER', N'Audit Log Folder')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'AUDIT_LOG_MAX_SIZE', N'Maximum audit log file size')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'AUDIT_LOG_PER_PROFILE', N'Create per-Profile audit log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'EXCH_SVR', N'Exchange Server Name')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'IGNORE_ACCESS_DENIED', N'Ignore if access denied')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'IGNORE_CAPTURED', N'Ignore captured items')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'IGNORE_PROCESSED', N'Ignore processed item')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'IGNORE_PROCESSED_CURRENT', N'Ignore item processed by current profile')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'POST_ERROR_ACTION', N'Post Processing action if error occurs')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'POST_ERROR_ACTION_VAL', N'Post Processing action value if error occurs')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'POST_ERROR_OVER', N'Override default settings (error file handling)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'POST_TARGET_ACTION', N'Post Processing Target Action')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'POST_TARGET_FILE', N'Post Processing Target File')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'POST_TARGET_NR_ACT', N'Post Processing Target No Rule Action')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'POST_TARGET_NR_FIL', N'Post Processing Target No Rule File')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'POST_TARGET_NR_OVER', N'Override default settings (target file not captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'POST_TARGET_OVER', N'Override default settings (target file captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'PREVIEW_MODE', N'Run PST Locator in preview mode')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'SCHED_DETAIL', N'Scheduling details')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'SCHED_END', N'Scheduled task duration')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'SCHED_OVER', N'Override default scheduling settings')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'SCHED_STARTTIME', N'Scheduled task start time')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_LOC', N'SCHED_TYPE', N'Schedule type')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'ATTACH_ADD_LINK', N'Add link for attachments')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'ATTACH_OPTION', N'Attachment options')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'ATTACH_PRE', N'Attachment Name Prefix')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'AUDIT_LOG_ENABLE', N'Enable Audit Log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'AUDIT_LOG_FIELDS', N'Fields to include in audit log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'AUDIT_LOG_FOLDER', N'Audit Log Folder')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'AUDIT_LOG_MAX_SIZE', N'Maximum audit log file size')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'AUDIT_LOG_PER_PROFILE', N'Create per-Profile audit log')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'BODY_ADD_LINK', N'Add link for body')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'BODY_COUNT', N'Characters to leave in body')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'CAP_NOTIFIC_TYPE', N'Notification type for tagging email')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'CAP_NOTIFICATION', N'Tag email as captured')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'CAPTURE_ATTACHMENTS', N'Capture Attachments')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'CAPTURE_EMAIL', N'Capture Email')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'DUP_DB_LOCATION', N'Duplicate Database Location Type')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'DUP_DB_NAME', N'Duplicate Database Name')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'DUP_DB_PASS', N'Duplciate Database User Password')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'DUP_DB_SERVER', N'Duplicate Database Server')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'DUP_DB_USER', N'Duplicate Database User')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'DUP_ENABLE', N'Enable Duplicate Detection')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'DUP_ENABLE_CHECK', N'Enable Duplicate Check')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'DUP_EXPIRY_TIME', N'Duplicate Entry Expirty Time')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'DUP_PROFILE_OPTIONS', N'Duplicate Check Options')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'EMAIL_PAREN', N'Email Address Parentheses')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'EMAILFILEEXT', N'Email File Extension')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'EMAILFORMAT', N'Email File Format')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'ENABLE_LINKS', N'Enable Links')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'EXCH_SVR', N'Exchange Server Name')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'IGNORE_PROCESSED', N'Ignore processed item')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'LEAVE_ATTACHMENTS', N'Leave Attachments in Email')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'LINK_ATTACH_TEXT', N'Descriptive text for attachment link')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'LINK_EMAIL_TEXT', N'Descriptive text for email link')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'LINK_POSITION', N'Position of link in body')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'NOTIFICATION_TYPE', N'Notification type for email capture')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'NULL_SUBJ_TXT', N'Text to use is subject is blank')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'OWNER_SHORTCUT_ACTION', N'PST owner shortcut mailbox options')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'OWNER_SHORTCUT_VAL', N'Value assoicated with OWNER SHORTCUT_ACTION')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'POST_ERROR_ACTION', N'Post Processing action if error occurs')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'POST_ERROR_ACTION_VAL', N'Post Processing action value if error occurs')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'POST_ERROR_OVER', N'Override default settings (error file handling)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'POST_METADATA_NR_OVER', N'Override default settings (metadata file not captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'POST_METADATA_OVER', N'Override default settings (metadata file captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'POST_TARGET_ACTION', N'Post Processing Target Action')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'POST_TARGET_NR_ACT', N'Post Processing Target No Rule Action')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'POST_TARGET_NR_OVER', N'Override default settings (target file not captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'POST_TARGET_OVER', N'Override default settings (target file captured)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'UNICODEMSG_FLG', N'Write MSG Files in Unicode Format')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'PST_PARSER', N'USER_NOTIFICATION', N'Notify user email has been captured')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'RETENTION', N'RETENTION_CLEAN_INTERVAL', N'Retention cleanup interval')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'RETENTION', N'RETENTION_FOLDER', N'Retention Log Folder')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'RETENTION', N'RETENTION_PERIOD_FILES', N'Retention period for captured files')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'POST_ERROR_ACTION', N'Post Processing action if error occurs')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'POST_ERROR_ACTION_VAL', N'Post Processing action value if error occurs')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'POST_ERROR_OVER', N'Override default settings (error file handling)')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'POST_METADATA_ACTION_VAL', N'Post Processing Metdata Action Value')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'POST_METADATA_NR_ACT_VAL', N'Post Processing Metdata No Rule Action Value')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'POST_METADATA_NR_SAME_DOC', N'Use same post action as target no rule')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'POST_METADATA_SAME_DOC', N'Use same post action as target')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'POST_TARGET_ACTION_VAL', N'Post Processing Target Action Value')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'POST_TARGET_NR_ACTION_VAL', N'Post Processing Target No Rule Action Value')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'RETENTION_CLEAN_INTERVAL', N'Log file cleanup interval')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'RETENTION_ENABLE_AUDIT', N'Enable audit file retention')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'RETENTION_ENABLE_LOGS', N'Enable log file retention')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'RETENTION_PERIOD_AUDIT', N'Retention period for audit files')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'SYSTEM', N'RETENTION_PERIOD_LOGS', N'Retention period for log files')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'TIFF', N'TIFF_EXCLUDE', N'File types to exclude')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'TIFF', N'TIFF_OPTIONS', N'TIFF Rendering Options')
INSERT INTO component_config_code (comp_code, cccd_code, cccd_name) VALUES (N'TIFF', N'TIFF_PRINTER', N'TIFF Printer Name')
go

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'AUDIT_LOG_ENABLE', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'AUDIT_LOG_FIELDS', 1, NULL)
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'AUDIT_LOG_FOLDER', 1, NULL)
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'AUDIT_LOG_MAX_SIZE', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'AUDIT_LOG_PER_PROFILE', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'DUP_DB_LOCATION', 1, '0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'DUP_DB_NAME', 1, NULL)
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'DUP_DB_PASS', 1, NULL)
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'DUP_DB_SERVER', 1, NULL)
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'DUP_DB_USER', 1, NULL)
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'DUP_ENABLE', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'DUP_ENABLE_CHECK', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'DUP_EXPIRY_TIME', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'DUP_PROFILE_OPTIONS', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'IGNORE_CAPTURED', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'IGNORE_PROCESSED', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'IGNORE_PROCESSED_CURRENT', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'POST_ERROR_ACTION', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'POST_ERROR_OVER', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'SCHED_DETAIL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'SCHED_END', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'SCHED_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'SCHED_STARTTIME', 1, N'00:00:00')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'SCHED_TYPE', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'AUDIT_LOG_ENABLE', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'AUDIT_LOG_FIELDS', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'AUDIT_LOG_FOLDER', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'AUDIT_LOG_MAX_SIZE', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'AUDIT_LOG_PER_PROFILE', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'ENABLE_NOT', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'IGNORE_CAPTURED', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'IGNORE_PROCESSED', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'P8PO_DOCURI', 1, N'%UNC_PATH%')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'P8PO_MIMETYPE', 1, N'application/x-filenet-external')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'POST_ERROR_ACTION', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'POST_ERROR_OVER', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'POST_METADATA_ACTION', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'POST_METADATA_NR_ACT_VAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'POST_METADATA_NR_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'POST_METADATA_NR_SAME_DOC', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'POST_METADATA_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'POST_METADATA_SAME_DOC', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'POST_TARGET_ACTION', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'POST_TARGET_NR_ACT', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'POST_TARGET_NR_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'POST_TARGET_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'SCHED_DETAIL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'SCHED_END', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'SCHED_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'SCHED_STARTTIME', 1, N'00:00:00')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'FS_CONN', N'SCHED_TYPE', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'AUDIT_LOG_ENABLE', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'AUDIT_LOG_FIELDS', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'AUDIT_LOG_FOLDER', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'AUDIT_LOG_MAX_SIZE', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'AUDIT_LOG_PER_PROFILE', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'DUP_DB_LOCATION', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'DUP_DB_NAME', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'DUP_DB_PASS', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'DUP_DB_SERVER', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'DUP_DB_USER', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'DUP_ENABLE', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'DUP_ENABLE_CHECK', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'DUP_EXPIRY_TIME', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'DUP_PROFILE_OPTIONS', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'IGNORE_CAPTURED', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'IGNORE_PROCESSED', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'IGNORE_PROCESSED_CURRENT', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'POST_ERROR_ACTION', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'POST_ERROR_ACTION_VAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'POST_ERROR_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'SCHED_DETAIL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'SCHED_END', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'SCHED_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'SCHED_STARTTIME', 1, N'00:00:00')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'SCHED_TYPE', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'TIMESTAMP_ENABLE', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'AUDIT_LOG_ENABLE', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'AUDIT_LOG_FIELDS', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'AUDIT_LOG_FOLDER', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'AUDIT_LOG_MAX_SIZE', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'AUDIT_LOG_PER_PROFILE', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'EXCH_SVR', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'IGNORE_CAPTURED', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'IGNORE_PROCESSED_CURRENT', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'POST_ERROR_ACTION', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'POST_ERROR_ACTION_VAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'POST_ERROR_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'POST_TARGET_ACTION', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'POST_TARGET_FILE', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'POST_TARGET_NR_ACT', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'POST_TARGET_NR_FIL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'POST_TARGET_NR_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'POST_TARGET_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'SCHED_DETAIL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'SCHED_END', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'SCHED_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'SCHED_STARTTIME', 1, N'00:00:00')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_LOC', N'SCHED_TYPE', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'ATTACH_ADD_LINK', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'ATTACH_OPTION', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'AUDIT_LOG_ENABLE', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'AUDIT_LOG_FIELDS', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'AUDIT_LOG_FOLDER', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'AUDIT_LOG_MAX_SIZE', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'AUDIT_LOG_PER_PROFILE', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'BODY_ADD_LINK', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'BODY_COUNT', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'CAP_NOTIFIC_TYPE', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'CAP_NOTIFICATION', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'CAPTURE_ATTACHMENTS', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'CAPTURE_EMAIL', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'DUP_DB_LOCATION', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'DUP_DB_NAME', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'DUP_DB_PASS', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'DUP_DB_SERVER', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'DUP_DB_USER', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'DUP_ENABLE', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'DUP_ENABLE_CHECK', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'DUP_EXPIRY_TIME', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'DUP_PROFILE_OPTIONS', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'EMAILFILEEXT', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'EMAILFORMAT', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'ENABLE_LINKS', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'EXCH_SVR', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'LEAVE_ATTACHMENTS', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'LINK_ATTACH_TEXT', 1, N'Attachments for this message have been captured and can be found at:')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'LINK_EMAIL_TEXT', 1, N'This message has been captured and can be found at:')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'LINK_POSITION', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'NOTIFICATION_TYPE', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'NULL_SUBJ_TXT', 1, N'No Subject')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'OWNER_SHORTCUT_ACTION', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'OWNER_SHORTCUT_VAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'POST_ERROR_ACTION', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'POST_ERROR_ACTION_VAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'POST_ERROR_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'POST_METADATA_NR_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'POST_METADATA_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'POST_TARGET_NR_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'POST_TARGET_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'PST_PARSER', N'USER_NOTIFICATION', 1, N'3')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'RETENTION', N'RETENTION_CLEAN_INTERVAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'RETENTION', N'RETENTION_FOLDER', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'RETENTION', N'RETENTION_PERIOD_FILES', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'POST_ERROR_ACTION', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'POST_ERROR_ACTION_VAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'POST_ERROR_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'POST_METADATA_ACTION_VAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'POST_METADATA_NR_ACT_VAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'POST_METADATA_NR_SAME_DOC', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'POST_METADATA_SAME_DOC', 1, N'1')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'POST_TARGET_ACTION_VAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'POST_TARGET_NR_ACTION_VAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'RETENTION_CLEAN_INTERVAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'RETENTION_ENABLE_AUDIT', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'RETENTION_ENABLE_LOGS', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'RETENTION_PERIOD_AUDIT', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'SYSTEM', N'RETENTION_PERIOD_LOGS', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'TIFF', N'TIFF_EXCLUDE', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'TIFF', N'TIFF_OPTIONS', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'TIFF', N'TIFF_PRINTER', 1, N'')
go

UPDATE document_type SET dcty_name=N'Email' WHERE dcty_code=N'EXCH_EMAIL'
go

insert into class_property_data_type_code (cpdc_code,cpdc_name) values ( N'STRING',N'String')
insert into class_property_data_type_code (cpdc_code,cpdc_name) values ( N'NUMBER',N'Number')
insert into class_property_data_type_code (cpdc_code,cpdc_name) values ( N'DATETIME',N'Datetime')
insert into captured_document_state_code (cdst_code,cdst_name) values ( N'RESERVED',N'Reserved')
insert into captured_document_state_code (cdst_code,cdst_name) values ( N'COMMITTED',N'Committed')
insert into monitored_location_optval_code (movc_code,movc_name) values ( N'MAPI_LOCATION',N'MAPI config file location')
insert into repository_class_config_code (rccc_code,rccc_name) values ( N'FORMAT_TYPE',N'Format Type')
insert into repository_class_config_code (rccc_code,rccc_name) values ( N'DELIMITER',N'Delimter')
insert into repository_class_config_code (rccc_code,rccc_name) values ( N'TEXT_QUALIFIER',N'Text Qualifier')
insert into repository_document_type_code (rdty_code,rdty_name) values ( N'EM_NATIVE',N'Email Native Format')
insert into repository_document_type_code (rdty_code,rdty_name) values ( N'EM_TEXT',N'Email Text Format')
insert into repository_document_type_code (rdty_code,rdty_name) values ( N'EM_ATTACH',N'Email Attachment')
go

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'POST_ERROR_ACTION_VAL', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'POST_TARGET_ACTION', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'POST_TARGET_NR_ACT', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'POST_TARGET_NR_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'EXCH_CONN', N'POST_TARGET_OVER', 1, N'0')
go

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'POST_TARGET_ACTION', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'POST_TARGET_NR_ACT', 1, N'')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'POST_TARGET_NR_OVER', 1, N'0')
INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) VALUES (N'LOTUS_CONN', N'POST_TARGET_OVER', 1, N'0')
go

update ex_conn
set ex_conn.coco_value = sys_conn.coco_value
from component_config_option ex_conn
,component_config_option sys_conn
where ex_conn.cccd_code = sys_conn.cccd_code
and ex_conn.asvr_id = 1
and ex_conn.comp_code = 'EXCH_CONN'
and sys_conn.comp_code = 'SYSTEM'
go

update ex_conn
set ex_conn.coco_value = sys_conn.coco_value
from component_config_option ex_conn
,component_config_option sys_conn
where ex_conn.cccd_code = sys_conn.cccd_code
and ex_conn.asvr_id = 1
and ex_conn.comp_code = 'LOTUS_CONN'
and sys_conn.comp_code = 'SYSTEM'
go

update filter_rule set dcty_code = 'EXCH_EMAIL'
go

set identity_insert filter_rule on
insert into filter_rule (frul_id, frul_name, frul_active_flag, frul_created_date, frul_modified_date, frul_deleted_flag, rvty_code, frul_always_true_flag, dcty_code)
values (0,'Global True Rule',1,getdate(),getdate(),0,'FIRSTTRUE',1,NULL)
set identity_insert filter_rule off
go

update archive_item_security
set dcty_code = NULL
go

INSERT INTO repository_archive_option (aprf_id, rocd_code, rpty_code, ropt_value) 
SELECT aprf_id, N'MINORVER',N'P8_CE', N'0'
from repository_archive_option
where rocd_code = 'DOCLASS'
and rpty_code = 'P8_CE'
go

INSERT INTO repository_archive_option (aprf_id, rocd_code, rpty_code, ropt_value) 
SELECT aprf_id, N'CREATEFLD',N'P8_CE', N'0'
from repository_archive_option
where rocd_code = 'DOCLASS'
and rpty_code = 'P8_CE'
go

alter table archive_server add asvr_temp_flag tinyint NOT NULL DEFAULT 0
go

update archive_server set asvr_temp_flag = 0 
go

INSERT INTO archive_server (asvr_name, rpty_code, asty_code, dcty_code, asvr_deleted_flag, asvr_active_flag, aprf_id, comp_code, asvr_temp_flag) 
SELECT archive_profile.aprf_name, repository.rpty_code, N'AGENT', archive_profile.dcty_code, archive_profile.aprf_deleted_flag, archive_profile.aprf_active_flag, archive_profile.aprf_id, N'UFI', archive_profile.aprf_temp_flag
from archive_profile
,repository
where archive_profile.repo_id = repository.repo_id
go

update expression_value set eval_regexp_replace_mode_flag = 0 where exvt_code = 'REGEXP'
go

update filter_rule_monitored_location
set source_asvr_id = asvr_id

update filter_rule_monitored_location
set filter_rule_monitored_location.target_asvr_id = asvr.asvr_id
from filter_rule_monitored_location
,archive_server asvr
where filter_rule_monitored_location.aprf_id = asvr.aprf_id
and asty_code = 'AGENT'

update archive_server 
set aprf_id = NULL
,comp_code = source_server.ssty_code + '_CONN'
from source_server
where asty_code = 'MONPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) 
SELECT source_server.ssty_code + '_CONN', N'DUP_ENABLE_CHECK', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'MONPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
SELECT source_server.ssty_code + '_CONN', N'DUP_PROFILE_OPTIONS', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'MONPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) 
SELECT source_server.ssty_code + '_CONN', N'IGNORE_CAPTURED', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'MONPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
 SELECT source_server.ssty_code + '_CONN', N'IGNORE_PROCESSED', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'MONPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
 SELECT source_server.ssty_code + '_CONN', N'IGNORE_PROCESSED_CURRENT', asvr_id, N'1'
from archive_server
,source_server
where asty_code = 'MONPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
 SELECT source_server.ssty_code + '_CONN', N'IGNORE_ACCESS_DENIED', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'MONPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) 
SELECT source_server.ssty_code + '_CONN', N'POST_ERROR_OVER', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'MONPROFILE'

update component_config_option
set comp_code = source_server.ssty_code + '_CONN'
from archive_server, component_config_option
,source_server
where archive_server.asty_code = 'MONPROFILE'
and archive_server.asvr_id = component_config_option.asvr_id
and component_config_option.comp_code = 'SYSTEM'
go

update archive_server 
set aprf_id = NULL
,comp_code = source_server.ssty_code + '_CONN'
from source_server
where asty_code = 'CWLPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) 
SELECT source_server.ssty_code + '_CONN', N'DUP_ENABLE_CHECK', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'CWLPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
SELECT source_server.ssty_code + '_CONN', N'DUP_PROFILE_OPTIONS', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'CWLPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) 
SELECT source_server.ssty_code + '_CONN', N'IGNORE_CAPTURED', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'CWLPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
 SELECT source_server.ssty_code + '_CONN', N'IGNORE_PROCESSED', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'CWLPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
 SELECT source_server.ssty_code + '_CONN', N'IGNORE_PROCESSED_CURRENT', asvr_id, N'1'
from archive_server
,source_server
where asty_code = 'CWLPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
 SELECT source_server.ssty_code + '_CONN', N'IGNORE_ACCESS_DENIED', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'CWLPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) 
SELECT N'EXCH_CONN', N'POST_ERROR_OVER', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'CWLPROFILE'

update component_config_option
set comp_code = source_server.ssty_code + '_CONN'
from archive_server, component_config_option, source_server
where archive_server.asty_code = 'CWLPROFILE'
and archive_server.asvr_id = component_config_option.asvr_id
and component_config_option.comp_code = 'SYSTEM'
go

update archive_server 
set archive_server.aprf_id = filter_rule_monitored_location.aprf_id
,archive_server.comp_code = source_server.ssty_code + '_CONN'
from archive_server
,filter_rule_monitored_location
,source_server
where archive_server.asty_code = 'CLTPROFILE'
and archive_server.asvr_id = filter_rule_monitored_location.asvr_id

update monitored_location
set monitored_location.ssvr_id = NULL
from monitored_location
,archive_server
where monitored_location.asvr_id = archive_server.asvr_id
and archive_server.asty_code = 'CLTPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) 
SELECT source_server.ssty_code + '_CONN', N'DUP_ENABLE_CHECK', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'CLTPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
SELECT source_server.ssty_code + '_CONN', N'DUP_PROFILE_OPTIONS', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'CLTPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) 
SELECT source_server.ssty_code + '_CONN', N'IGNORE_CAPTURED', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'CLTPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
 SELECT source_server.ssty_code + '_CONN', N'IGNORE_PROCESSED', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'CLTPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
 SELECT source_server.ssty_code + '_CONN', N'IGNORE_PROCESSED_CURRENT', asvr_id, N'1'
from archive_server
,source_server
where asty_code = 'CLTPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
 SELECT source_server.ssty_code + '_CONN', N'IGNORE_ACCESS_DENIED', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'CLTPROFILE'

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value) 
SELECT source_server.ssty_code + '_CONN', N'POST_ERROR_OVER', asvr_id, N'0'
from archive_server
,source_server
where asty_code = 'CLTPROFILE'

update component_config_option
set comp_code = source_server.ssty_code + '_CONN'
from archive_server, component_config_option, source_server
where archive_server.asty_code = 'CLTPROFILE'
and archive_server.asvr_id = component_config_option.asvr_id
and component_config_option.comp_code = 'SYSTEM'
go

update component set invt_code = 'REMOTE' where comp_code = 'UFI'
update component set invt_code = 'REMOTE' where comp_code = 'TIFF'
update component set comp_remote_interface = 'tcp://localhost:14562/DocumentConversion' where comp_code = 'TIFF'
go

insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'EXCH_CONN',N'RESOLVE_DIST',N'Resolve Distribution Lists')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'RESOLVE_DIST',N'Duplicate Entry Expirty Time')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'PST_PARSER',N'RESOLVE_DIST',N'Duplicate Entry Expirty Time')
go

INSERT INTO component_config_option (comp_code, cccd_code, asvr_id, coco_value)
 SELECT source_server.ssty_code + '_CONN', N'RESOLVE_DIST', asvr_id, N'1'
from archive_server
,source_server
where asty_code = 'CLTPROFILE'
or asty_code = 'CWLPROFILE'
or asty_code = 'MONPROFILE'

CREATE INDEX xie1captured_document ON captured_document
(
       cdoc_created_date
)
go

CREATE INDEX xie1repository_document ON repository_document
(
       rdoc_created_date
)
go

update document_type set dcty_name = N'PST Archive File' where dcty_code = 'PST_LOC'
update document_type set dcty_name = N'PST Email' where dcty_code = 'PST_PARSER'
go

update component_config_option set coco_value = '16' where comp_code = 'PST_LOC' and cccd_code = 'POST_TARGET_ACTION' and asvr_id = 1
update component_config_option set coco_value = '16' where comp_code = 'PST_LOC' and cccd_code = 'POST_TARGET_NR_ACT' and asvr_id = 1
update component_config_option set coco_value = '0' where comp_code = 'PST_LOC' and cccd_code = 'POST_ERROR_ACTION' and asvr_id = 1
update component_config_option set coco_value = '0' where comp_code = 'PST_PARSER' and cccd_code = 'USER_NOTIFICATION' and asvr_id = 1
update component_config_option set coco_value = '1' where comp_code = 'PST_PARSER' and cccd_code = 'CAP_NOTIFICATION' and asvr_id = 1
go

insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'PST_PARSER',N'IGNORE_PROCESSED',1,N'1')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'PST_LOC',N'IGNORE_PROCESSED',1,N'1')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'PST_PARSER',N'ATTACH_PRE',1,N'(A)')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'PST_PARSER',N'RESOLVE_DIST',1,N'1')
go

insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'QUEUESIZE',N'Processing queue wait threshold')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'QUEUEPAUSEDWAIT',N'Do not process if queue size over queue wait threshold')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'PIPELINETHREADS',N'Processing Threads')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'CACHESERVER',N'Cache Server')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'CACHEDBPATH',N'Cache Database Path')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'ADDRESSBOOKUSEPUBLIC',N'Use Public Address Book')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'ADDRESSBOOKUSEPRIVATE',N'Use Private Address Book')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'ADDRESSSECURITYPROPERTY',N'Address Security Property')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'ICONCHANGEMODE',N'Icon Change Mode')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'ICONNUMBER',N'Icon Number')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'CRAWLERVIEWPROFILE',N'Crawler View (Profile)')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'CRAWLERVIEWCLIENT',N'Crawler View (Client Database)')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'CLIENTCAPTURE',N'Enable Client Capture')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'SAVEMETADATA',N'Save Metadata To Folder')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'SAVEMETADATAPATH',N'Save Metadata Path')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'DELETEEXPORTEDFILES',N'Delete Exported Files')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'CACHECLEANUPMODE',N'Cache Cleanup Mode')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'LOTUS_CONN',N'LOGVERBOSETRACE',N'Enable extended trace logging')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'EXCH_CONN',N'SAVETEXTWITHFORMATTING',N'Save Email With Formatting')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'EXCH_CONN',N'GENERATEPLAINTEXTSHORTCUT',N'Generate Plain Text Shortcut')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'EXCH_CONN',N'REDUCEMSGSIZE',N'Reduce MSG File Size')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'EXCH_CONN',N'WRITEDEBUGXML',N'Save Metadata To Folder')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'EXCH_CONN',N'PROCESSINGTHREADS',N'Processing Threads')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'EXCH_CONN',N'PROCESSINGQUEUESIZE',N'Processing Queue Size')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'EXCH_CONN',N'LOGVERBOSETRACE',N'Enable extended trace logging')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'PST_PARSER',N'SAVETEXTWITHFORMATTING',N'Save Email With Formatting')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'PST_PARSER',N'GENERATEPLAINTEXTSHORTCUT',N'Generate Plain Text Shortcut')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'PST_PARSER',N'REDUCEMSGSIZE',N'Reduce MSG File Size')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'PST_PARSER',N'WRITEDEBUGXML',N'Save Metadata To Folder')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'PST_LOC',N'PROCESSINGTHREADS',N'Processing Threads')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'PST_LOC',N'PROCESSINGQUEUESIZE',N'Processing Queue Size')
insert into component_config_code (comp_code,cccd_code,cccd_name) values ( N'PST_LOC',N'LOGVERBOSETRACE',N'Enable extended trace logging')
go

insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'QUEUESIZE',1,N'500')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'QUEUEPAUSEDWAIT',1,N'1')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'PIPELINETHREADS',1,N'3')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'CACHESERVER',1,N'')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'CACHEDBPATH',1,N'eMgr\Cache.nsf')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'ADDRESSBOOKUSEPUBLIC',1,N'1')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'ADDRESSBOOKUSEPRIVATE',1,N'1')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'ADDRESSSECURITYPROPERTY',1,N'ShortName')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'ICONCHANGEMODE',1,N'3')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'ICONNUMBER',1,N'30')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'CRAWLERVIEWPROFILE',1,N'')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'CRAWLERVIEWCLIENT',1,N'')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'CLIENTCAPTURE',1,N'1')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'SAVEMETADATA',1,N'0')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'SAVEMETADATAPATH',1,N'')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'DELETEEXPORTEDFILES',1,N'1')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'CACHECLEANUPMODE',1,N'0')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'LOTUS_CONN',N'LOGVERBOSETRACE',1,N'0')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'EXCH_CONN',N'SAVETEXTWITHFORMATTING',1,N'0')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'EXCH_CONN',N'GENERATEPLAINTEXTSHORTCUT',1,N'0')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'EXCH_CONN',N'REDUCEMSGSIZE',1,N'0')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'EXCH_CONN',N'WRITEDEBUGXML',1,N'0')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'EXCH_CONN',N'PROCESSINGTHREADS',1,N'10')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'EXCH_CONN',N'PROCESSINGQUEUESIZE',1,N'10')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'EXCH_CONN',N'LOGVERBOSETRACE',1,N'0')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'PST_PARSER',N'SAVETEXTWITHFORMATTING',1,N'0')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'PST_PARSER',N'GENERATEPLAINTEXTSHORTCUT',1,N'0')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'PST_PARSER',N'REDUCEMSGSIZE',1,N'0')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'PST_PARSER',N'WRITEDEBUGXML',1,N'0')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'PST_LOC',N'PROCESSINGTHREADS',1,N'10')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'PST_LOC',N'PROCESSINGQUEUESIZE',1,N'10')
insert into component_config_option (comp_code,cccd_code,asvr_id,coco_value) values ( N'PST_LOC',N'LOGVERBOSETRACE',1,N'0')
go

update component_config_option set coco_value = '0' where comp_code = 'LOTUS_CONN' and cccd_code = 'ADDRESSBOOKUSEPRIVATE'
go

update eval_new
set eval_new.eval_text_value = convert(nvarchar(255), cast(eval_old.eval_text_value as datetime) , 101) + ' ' + convert(nvarchar(255), cast(eval_old.eval_text_value as datetime) , 108)
from expression_value eval_new, expression_value eval_old
where eval_new.eval_id = eval_old.eval_id and     
    eval_new.eval_id in
    (select expression_value.eval_id     
    from property_mapping, expression_value
    where property_mapping.rpdt_code = N'idmTypeDate' and
        property_mapping.pmap_id = expression_value.pmap_id)
go